@@ -24,10 +24,10 @@ os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"
 
 import warnings
 
-from autotrain.logging import custom_logger as logger
+from autotrain.logging import custom_logger as logger  # noqa: F401
 
 
 warnings.filterwarnings("ignore", category=UserWarning, module="tensorflow")
 
 
-__version__ = "0.6.35"
+__version__ = "0.7.8"
