@@ -1,13 +1,10 @@
 import argparse
 import json
-import os
-
-from huggingface_hub import HfApi
 
 from autotrain import logger
+from autotrain.trainers.common import monitor, pause_space
 from autotrain.trainers.generic import utils
 from autotrain.trainers.generic.params import GenericParams
-from autotrain.utils import monitor
 
 
 def parse_args():
@@ -26,6 +23,9 @@ def run(config):
     logger.info("Downloading data repo...")
     utils.pull_dataset_repo(config)
 
+    logger.info("Unintalling requirements...")
+    utils.uninstall_requirements(config)
+
     # install the requirements
     logger.info("Installing requirements...")
     utils.install_requirements(config)
@@ -34,16 +34,7 @@ def run(config):
     logger.info("Running command...")
     utils.run_command(config)
 
-    if "SPACE_ID" in os.environ:
-        # shut down the space
-        logger.info("Pausing space...")
-        api = HfApi(token=config.token)
-        api.pause_space(repo_id=os.environ["SPACE_ID"])
-
-    if "ENDPOINT_ID" in os.environ:
-        # shut down the endpoint
-        logger.info("Pausing endpoint...")
-        utils.pause_endpoint(config)
+    pause_space(config)
 
 
 if __name__ == "__main__":
